@@ -43,7 +43,9 @@ class Connection(Stateful):
         import amqpstorm
         ssl_options = {
             'context': ssl.create_default_context(cafile='cacert.pem'),
-            'server_hostname': 'rmq.eandersson.net'
+            'server_hostname': 'rmq.eandersson.net',
+            'check_hostname': True,        # New 2.8.0, default is False
+            'verify_mode': 'required',     # New 2.8.0, default is 'none'
         }
         connection = amqpstorm.Connection(
             'rmq.eandersson.net', 'guest', 'guest', port=5671,
