@@ -2,9 +2,9 @@ from amqpstorm.management import ManagementApi
 from amqpstorm.tests import HTTP_URL
 from amqpstorm.tests import PASSWORD
 from amqpstorm.tests import USERNAME
-from amqpstorm.tests.utility import TestFunctionalFramework
-from amqpstorm.tests.utility import retry_function_wrapper
-from amqpstorm.tests.utility import setup
+from amqpstorm.tests.functional.utility import TestFunctionalFramework
+from amqpstorm.tests.functional.utility import retry_function_wrapper
+from amqpstorm.tests.functional.utility import setup
 
 
 class ApiChannelFunctionalTests(TestFunctionalFramework):
